<?xml version="1.0" encoding="windows-1251"?>
<!DOCTYPE xsl:stylesheet>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output xmlns="http://www.w3.org/TR/xhtml1/strict" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" encoding="Windows-1251" indent="yes" method="html" omit-xml-declaration="no" version="1.0" media-type="text/xml"/>

	<xsl:template match="/">
		<xsl:apply-templates select="/document/item"/>
	</xsl:template>

	<xsl:template match="/document/item">
		<!--  ID       $parent_group_id -->
		<xsl:variable name="parent_group_id" select="/document/information_system/parent_group_id"/>

		<h1>
			<xsl:value-of disable-output-escaping="yes" select="item_name"/>
		</h1>
		<!-- ============= -->
		<!--    -->
		<!-- ============= -->
		<p>
			<xsl:apply-templates select="//group[@id=$parent_group_id]" mode="goup_path"/>
		</p>

		<!--    -->
		<xsl:variable name="file_type">
			<xsl:call-template name="file_type">
				<xsl:with-param name="str" select="item_propertys/item_property[@xml_name = 'file']/property_file_path" />
			</xsl:call-template>
		</xsl:variable>

		<!--     ( ) -->
		<xsl:if test="item_small_image != ''">
			<div class="left">
				<img src="{item_small_image}" class="news_img" alt="" style="padding: 2px; border: 1px solid #C6BEA7;"/>
			</div>
		</xsl:if>

		<!--   -->
		<xsl:variable name="width_img">
			<xsl:choose>
				<xsl:when test="item_small_image != ''">
					<xsl:value-of select="item_small_image/@width + 20" />
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<div style="padding-left: {$width_img}px;">
			<xsl:if test="item_description != ''">
				<div>
					<xsl:value-of disable-output-escaping="yes" select="item_text"/>
				</div>
			</xsl:if>
			<xsl:if test="item_propertys/item_property[@xml_name='file']/property_file_path != ''">
				<!--   -  -->
				<xsl:if test="$file_type = 'bmp.gif' or $file_type = 'png.gif'	or $file_type = 'jpg.gif' or $file_type = 'gif.gif'">	
					<b>:</b>&#xA0;<xsl:value-of select="item_propertys/item_property[@xml_name = 'file']/property_file_path/@width" />&#215;<xsl:value-of select="item_propertys/item_property[@xml_name = 'file']/property_file_path/@height" />
					<br/>
				</xsl:if>

				<b>:</b>&#xA0;<xsl:value-of select="format-number(item_propertys/item_property[@xml_name = 'file']/property_file_path/@size div 1024, '0.##')" /> <br/>
				<img src="/hostcmsfiles/images/icons/{$file_type}" style="margin: 0 5px -3px 0;"/>
				<a href="{item_propertys/item_property[@xml_name='file']/property_file_path}" target="_blank"></a>
			</xsl:if>
		</div>

		<div class="clearing"></div>
	</xsl:template>

	<!-- ======================================================== -->
	<!--       .  -->
	<!-- ======================================================== -->
	<xsl:template match="group" mode="goup_path">
		<xsl:variable name="parent_id" select="@parent_id"/>

		<!--     -->
		<xsl:apply-templates select="//group[@id=$parent_id]" mode="goup_path"/>

		<xsl:if test="@parent_id=0">
			<a href="{/document/information_system/url}">
				<xsl:value-of disable-output-escaping="yes" select="/document/information_system/name"/>
			</a>
		</xsl:if>
		<span class="path_arrow">&#x2192;</span>
		<a href="{/document/information_system/url}{fullpath}">
			<xsl:value-of disable-output-escaping="yes" select="name"/>
		</a>
	</xsl:template>

	<!--      -->
	<xsl:template name="file_type">
		<xsl:param name="str"/>

		<xsl:variable name="sub_str">
			<xsl:value-of select="substring-after($str, '.')" />
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$sub_str = ''">file.gif</xsl:when>
			<xsl:when test="$sub_str = 'sql'">sql.gif</xsl:when>
			<xsl:when test="$sub_str = 'css'">css.gif</xsl:when>
			<xsl:when test="$sub_str = 'gif'">gif.gif</xsl:when>
			<xsl:when test="$sub_str = 'bmp'">bmp.gif</xsl:when>
			<xsl:when test="$sub_str = 'png'">png.gif</xsl:when>
			<xsl:when test="$sub_str = 'ico'">image.gif</xsl:when>
			<xsl:when test="$sub_str = 'xml'">xml.gif</xsl:when>
			<xsl:when test="$sub_str = 'xsl'">xsl.gif</xsl:when>
			<xsl:when test="$sub_str = 'rar'">rar.gif</xsl:when>
			<xsl:when test="$sub_str = 'pdf'">pdf.gif</xsl:when>
			<xsl:when test="$sub_str = 'rb'">rb.gif</xsl:when>
			<xsl:when test="$sub_str = 'mdb'">mdb.gif</xsl:when>
			<xsl:when test="$sub_str = 'h'">h.gif</xsl:when>
			<xsl:when test="$sub_str = 'xls'">xls.gif</xsl:when>
			<xsl:when test="$sub_str = 'cpp'">cpp.gif</xsl:when>
			<xsl:when test="$sub_str = 'chm'">chm.gif</xsl:when>
			<xsl:when test="$sub_str = 'doc' or $sub_str = 'docx'">doc.gif</xsl:when>
			<xsl:when test="$sub_str = 'htm' or $sub_str = 'html'">html.gif</xsl:when>
			<xsl:when test="$sub_str = 'php' or $sub_str = 'php3'">php.gif</xsl:when>
			<xsl:when test="$sub_str = 'jpg' or $sub_str = 'jpeg'">jpg.gif</xsl:when>
			<xsl:when test="$sub_str = 'fla' or $sub_str = 'fla'">flash.gif</xsl:when>
			<xsl:when test="$sub_str = 'zip' or $sub_str = 'gz' or $sub_str = '7z'">zip.gif</xsl:when>
			<xsl:when test="$sub_str = 'cdr' or $sub_str = 'ai' or $sub_str = 'eps'">vector.gif</xsl:when>
			<xsl:when test="$sub_str = 'ppt' or $sub_str = 'pptx' or $sub_str = 'pptm'">ppt.gif</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="file_type">
					<xsl:with-param name="str" select="$sub_str"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>